// ===============================================
// File:		GLSettings.cxx
// Description:		setup the OpenGL state machine
// Current:             Sept 28th 1999
// Author(s):		Thomas Kern
// ===============================================

/*
 *        thk VRML-Viewer (based on OpenGL)
 *  it shows static *.wrl files based on the VRML97 standard
 *
 *          Copyright (C) 1997-1999  Thomas Kern
 *                  All Rights Reserved
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Library General Public
 *   License as published by the Free Software Foundation; either
 *   version 2 of the License, or (at your option) any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Library General Public License for more details.
 *
 *   You should have received a copy of the GNU Library General Public
 *   License along with this library; if not, write to the Free
 *   Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * My email adress is: 
 *   Thomas.Kern@3Dsource.de 
 * 
 * You should find these files at: my homepage
 *   http://www.3Dsource.de
 *
 */


#ifndef GLSETTINGS_H
#define GLSETTINGS_H

//=====================================================================
//	INCLUDES AND DEFINES
//=====================================================================
//
#include <math.h>

#include "Tools.H" // will load windows.h if needed
#include "VRMLControl.H"

#define MAX_TRANSFORMS 20

// Darstellung dieser Quadranten im WC
//      |             .      |      .
//   q2 | q1             .q2o|q1o .
// -----|-----  mit:      .  |  .     
//   q3 | q4           q2u  .|.  q1u
//      |              --------------
//                     q3o . | . q4o
//                       .   |   .
//                     .  q3u|q4u  .
//
enum Quadrants {q1u, q1o, q2u, q2o, q3u, q3o, q4u, q4o, all};

//=====================================================================
//	STEUERUNG DES OPENGL-STATUS, als C-Funktionen realisiert, da OpenGL 
//  eine Status-Maschine darstellt (mehrere Instanzen sind nicht 
//  erwuenscht, ausserdem geht's so schneller (hoffentlich ;-)
//=====================================================================
//
void GLSetPerspective(int newWidth, int newHeight);
void GLReset(int newWidth, int newHeight);
void coordDir(GLfloat xp[3], GLfloat zp[3]);
void GLnewFrame();

// Eye
void GLAddEyeMove(GLfloat addZ);
void GLAddEyeRot(GLfloat addX, GLfloat addY, GLfloat addZ);
void GLSetEyePoint(GLfloat x, GLfloat y, GLfloat z);
void GLSetEyeRot(GLfloat angleX, GLfloat angleY, GLfloat angleZ);

void GLSetPlanes(GLdouble nearP, GLdouble farP);
void GLSetAngle(GLdouble angle);

// rendering
void GLSetLighting(boolean SetON);
void GLSetDrawStile(boolean SetON);
void GLSetCulling(boolean SetON);
void GLSetShading(boolean SetON);
void GLSetFog(boolean SetON);

// object
//void GLAddObjMove(GLfloat addZ);
//void GLAddObjRot(GLfloat addX, GLfloat addY, GLfloat addZ);
void GLCalcObjMatrix(Quadrants Quads[2]);
boolean GLCheckVisible(GLfloat point[3]);

// --------------------------------------------------------------------
#endif // GLSETTINGS_H
